@@ -2,14 +2,17 @@ context("Summarization")
 test_that("Simulation summary", {
   data("simulation_results")
   data("scenario_summary")
-  dat <- summarize_scenarios(simulation_results)
-  expect_equivalent(as.data.frame(dat), as.data.frame(scenario_summary))
+  summarized_scenarios <- summarize_scenarios(simulation_results)
+  expect_equivalent(as.data.frame(summarized_scenarios),
+                    as.data.frame(scenario_summary),
+                    tolerance = .01)
 })
+
 test_that("Simulation summary handles NAs for tc/diff exceedance", {
   data("simulation_results")
   simulation_results[1, "mean_tc_exceedance"] <- NA
-  simulation_results[simulation_results$scenario_id==18 &
-                       simulation_results$simulation==1, "mean_diff_exceedance"] <- NA
+  simulation_results[simulation_results$scenario_id == 18 &
+                       simulation_results$simulation == 1, "mean_diff_exceedance"] <- NA
   dat <- summarize_scenarios(simulation_results)
   expect_gt(dat[[54,"mean_tc_exceedance"]], 0)
 })
@@ -18,7 +21,11 @@ test_that("Domain summary", {
   data("simulation_results")
   data("domains")
   data("domain_summary")
-  expect_equivalent(summarize_domains(simulation_results), domain_summary)
+
+  summarized_domains <- summarize_domains(simulation_results)
+
+  expect_equivalent(as.data.frame(summarized_domains),
+                    as.data.frame(domain_summary), tolerance = 0.01)
 })
 
 test_that("Summarize to disk", {
